# -*- coding: utf-8 -

"""Test the created constraints against approved constraints.

This file is part of project oemof (github.com/oemof/oemof). It's copyrighted
by the contributors recorded in the version control history of the file,
available from its original location oemof/tests/tool_tests.py

SPDX-License-Identifier: MIT
"""

import os
import warnings

from nose.tools import assert_raises_regexp
from nose.tools import eq_
from nose.tools import ok_
from oemof.tools import debugging
from oemof.tools import economics
from oemof.tools.logger import define_logging
from oemof.tools.logger import extend_basic_path
from oemof.tools.logger import get_basic_path


def test_helpers():
    get_basic_path()
    ok_(os.path.isdir(os.path.join(os.path.expanduser('~'), '.oemof')))
    new_dir = extend_basic_path('test_xf67456_dir')
    ok_(os.path.isdir(new_dir))
    os.rmdir(new_dir)
    ok_(not os.path.isdir(new_dir))


def test_logger():
    filepath = define_logging()
    ok_(isinstance(filepath, str))
    ok_(filepath[-9:] == 'oemof.log')
    ok_(os.path.isfile(filepath))


def test_annuity():
    """Test annuity function of economics tool."""
    ok_(round(economics.annuity(1000, 10, 0.1)) == 163)
    ok_(round(economics.annuity(capex=1000, wacc=0.1, n=10, u=5)) == 264)
    ok_(round(economics.annuity(1000, 10, 0.1, u=5, cost_decrease=0.1)) == 222)


def test_annuity_exceptions():
    """Test out-of-bounds-error of the annuity tool."""
    msg = "Input arguments for 'annuity' out of bounds!"
    assert_raises_regexp(ValueError, msg, economics.annuity, 1000, 10, 2)
    assert_raises_regexp(ValueError, msg, economics.annuity, 1000, 0.5, 1)
    assert_raises_regexp(
        ValueError, msg, economics.annuity, 1000, 10, 0.1, u=0.3)
    assert_raises_regexp(
        ValueError, msg, economics.annuity, 1000, 10, 0.1, cost_decrease=-1)


def test_suspicious_usage_warning():
    msg = "My message."
    with warnings.catch_warnings(record=True) as w:
        warnings.warn(msg, debugging.SuspiciousUsageWarning)
        ok_(len(w) == 1)
        eq_(msg, str(w[-1].message))



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

import io
import re
from glob import glob
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext

from setuptools import find_packages
from setuptools import setup


def read(*names, **kwargs):
    with io.open(
        join(dirname(__file__), *names),
        encoding=kwargs.get("encoding", "utf8"),
    ) as fh:
        return fh.read()


long_description = (
        "%s\n%s"
        % (
            re.compile("^.. start-badges.*^.. end-badges", re.M | re.S).sub(
                "", read("README.rst")
            ),
            re.sub(":[a-z]+:`~?(.*?)`", r"``\1``", read("CHANGELOG.rst")),
        )
    )


setup(
    name="oemof.tools",
    version="0.4.0.rc.1",
    license="MIT",
    description="Tiny tools of the oemof project.",
    long_description_content_type="text/x-rst",
    long_description=long_description,
    author="oemof-developer-group",
    author_email="contact@oemof.org",
    url="https://github.com/oemof/oemof-tools",
    packages=["oemof"] + ["oemof." + p for p in find_packages("src/oemof")],
    package_dir={"": "src"},
    py_modules=[splitext(basename(path))[0] for path in glob("src/*.py")],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        # complete classifier list:
        # http://pypi.python.org/pypi?%3Aaction=list_classifiers
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Unix",
        "Operating System :: POSIX",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: Implementation :: CPython",
        # uncomment if you test on these interpreters:
        # 'Programming Language :: Python :: Implementation :: IronPython',
        # 'Programming Language :: Python :: Implementation :: Jython',
        # 'Programming Language :: Python :: Implementation :: Stackless',
        "Topic :: Utilities",
    ],
    project_urls={
        "Documentation": "https://oemof-tools.readthedocs.io/",
        "Changelog": (
            "https://oemof-tools.readthedocs.io/en/latest/changelog.html"
        ),
        "Issue Tracker": "https://github.com/oemof/oemof-tools/issues",
    },
    keywords=[
        # eg: 'keyword1', 'keyword2', 'keyword3',
    ],
    python_requires=">=3.6",
    install_requires=[
        # eg: 'aspectlib==1.1.1', 'six>=1.7',
    ],
    extras_require={
        # eg:
        #   'rst': ['docutils>=0.11'],
        #   ':python_version=="2.6"': ['argparse'],
    },
)
